==> zio-aws-elasticsearch_2.13-5.17.104.7-sources.jar: zio/aws/elasticsearch/model/DescribeOutboundCrossClusterSearchConnectionsRequest.scala <==
package zio.aws.elasticsearch.model
import java.lang.Integer
import zio.aws.elasticsearch.model.primitives.{NextToken, MaxResults}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeOutboundCrossClusterSearchConnectionsRequest(
    filters: Option[Iterable[zio.aws.elasticsearch.model.Filter]] = None,
    maxResults: Option[MaxResults] = None,
    nextToken: Option[NextToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest = {
    import DescribeOutboundCrossClusterSearchConnectionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest.ReadOnly =
    zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
      .wrap(buildAwsValue())
}
object DescribeOutboundCrossClusterSearchConnectionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest =
      zio.aws.elasticsearch.model
        .DescribeOutboundCrossClusterSearchConnectionsRequest(
          filters.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          maxResults.map(value => value),
          nextToken.map(value => value)
        )
    def filters: Option[List[zio.aws.elasticsearch.model.Filter.ReadOnly]]
    def maxResults: Option[MaxResults]
    def nextToken: Option[NextToken]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.elasticsearch.model.Filter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
  ) extends zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest.ReadOnly {
    override val filters
        : Option[List[zio.aws.elasticsearch.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticsearch.model.Filter.wrap(item)
        }.toList
      )
    override val maxResults: Option[MaxResults] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.elasticsearch.model.primitives.MaxResults(value))
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.elasticsearch.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
  ): zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-elasticsearch_2.13-5.20.22.2-sources.jar: zio/aws/elasticsearch/model/DescribeOutboundCrossClusterSearchConnectionsRequest.scala <==
package zio.aws.elasticsearch.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.elasticsearch.model.primitives.{NextToken, MaxResults}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeOutboundCrossClusterSearchConnectionsRequest(
    filters: Optional[Iterable[zio.aws.elasticsearch.model.Filter]] =
      Optional.Absent,
    maxResults: Optional[MaxResults] = Optional.Absent,
    nextToken: Optional[NextToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest = {
    import DescribeOutboundCrossClusterSearchConnectionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
      .builder()
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxResults.map(value => MaxResults.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest.ReadOnly =
    zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
      .wrap(buildAwsValue())
}
object DescribeOutboundCrossClusterSearchConnectionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest =
      zio.aws.elasticsearch.model
        .DescribeOutboundCrossClusterSearchConnectionsRequest(
          filters.map(value =>
            value.map { item =>
              item.asEditable
            }
          ),
          maxResults.map(value => value),
          nextToken.map(value => value)
        )
    def filters: Optional[List[zio.aws.elasticsearch.model.Filter.ReadOnly]]
    def maxResults: Optional[MaxResults]
    def nextToken: Optional[NextToken]
    def getFilters: ZIO[Any, AwsError, List[
      zio.aws.elasticsearch.model.Filter.ReadOnly
    ]] = AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, MaxResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
  ) extends zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest.ReadOnly {
    override val filters
        : Optional[List[zio.aws.elasticsearch.model.Filter.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.filters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticsearch.model.Filter.wrap(item)
          }.toList
        )
    override val maxResults: Optional[MaxResults] = zio.aws.core.internal
      .optionalFromNullable(impl.maxResults())
      .map(value => zio.aws.elasticsearch.model.primitives.MaxResults(value))
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.elasticsearch.model.primitives.NextToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest
  ): zio.aws.elasticsearch.model.DescribeOutboundCrossClusterSearchConnectionsRequest.ReadOnly =
    new Wrapper(impl)
}
